@@ -363,9 +363,7 @@ impl Config {
             for d in reader.lines() {
                 // Don't depend on the ISPC "stdlib" file which is output as a dependecy
                 let dep_name = d.unwrap();
-                if dep_name != "C:/iusers/aneshlya/ispc_upstream/stdlib.ispc" {
-                    self.print(&format!("cargo:rerun-if-changed={}", dep_name));
-                }
+                self.print(&format!("cargo:rerun-if-changed={}", dep_name));
             }
 
             // Push on the additional ISA-specific object files if any were generated
@@ -457,7 +455,7 @@ impl Config {
     fn default_args(&self) -> Vec<String> {
         let mut ispc_args = Vec::new();
         let opt_level = self.get_opt_level();
-        if self.get_debug() && opt_level == 0 {
+        if self.get_debug() {
             ispc_args.push(String::from("-g"));
         }
         if let Some(ref c) = self.cpu_target {
